<?php

namespace Drupal\unomi_connect;

use Drupal\Core\Config\ConfigFactoryInterface;
use GuzzleHttp\Client;
use GuzzleHttp\Psr7\Response;
use stdClass;

/**
 * UnomiConnect service.
 */
class UnomiConnect {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Constructs an UnomiConnect object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->configFactory = $config_factory;
  }

  /**
   * Get a client connection.
   *
   * @return \GuzzleHttp\Client
   *   The unomi client connection.
   */
  public function getUnomiClient() : Client {
    $unomiConnectSettings = $this->configFactory->get('unomi_connect.settings');
    $uri = $unomiConnectSettings->get('base_uri');
    $port = $unomiConnectSettings->get('port');
    $baseUri = $uri . ':' . $port;

    $client = new Client(['base_uri' => $baseUri]);
    return $client;
  }

  /**
   * Make Unomi Request.
   *
   * @param string $method
   *   The verb.
   * @param string $uri
   *   The uri.
   * @param object $stdClass
   *   The object to encode json.
   *
   * @return \GuzzleHttp\Psr7\Response
   *   The response.
   */
  public function makeRequest(string $method, string $uri, stdClass $stdClass = NULL) : Response {
    $unomiConnectSettings = $this->configFactory->get('unomi_connect.settings');
    $username = $unomiConnectSettings->get('username');
    $password = $unomiConnectSettings->get('password');

    $response = $this->getUnomiClient()->request($method, $uri, [
      'headers' => [
        'Content-Type' => "application/json",
      ],
      'auth' => [$username, $password],
      'json' => $stdClass,
    ]);

    return $response;
  }

}
