<?php

namespace Drupal\unomi_segments\Controller;

use Drupal\Core\Url;
use Drupal\unomi_connect\Controller\UnomiControllerBase;

/**
 * Returns responses for Unomi Segments routes.
 */
class UnomiSegmentsController extends UnomiControllerBase {

  /**
   * Builds the response.
   */
  public function index() {

    $segments = $this->getContents(
      $this->config('unomi_segments.settings')->get('segments_uri')
    );

    $header = [
      ['data' => $this->t('#')],
      ['data' => $this->t('Name')],
      ['data' => $this->t('Description')],
      ['data' => $this->t('Scope')],
      ['data' => $this->t('Tags')],
      ['data' => $this->t('Status')],
      ['data' => $this->t('Operations')],
    ];

    $rows = [];
    asort($segments);
    foreach ($segments as $segment) {

      $operations['edit'] = [
        'title' => $this->t('Delete'),
        'url' => Url::fromRoute('unomi_segments.delete_confirm', ['segmentId' => $segment->id]),
      ];

      $rows[$segment->id] = [
        'class' => ['draggable'],
        'data' => [
          'id' => $segment->id,
          'name' => $segment->name,
          'description' => $segment->description,
          'scope' => $segment->scope,
          'tags' => implode(', ', $segment->tags),
          'status' => $segment->enabled ? 'Enabled' : 'Disabled',
          'edit' => [
            'data' => [
              '#type' => 'operations',
              '#links' => $operations,
            ],
          ],
        ],
      ];
    }

    $output['states'] = [
      '#type' => 'table',
      '#header' => $header,
      '#rows' => $rows,
      '#attributes' => [
        'class' => ['devel-state-list'],
      ],
      'pager' => [
        '#type' => 'pager',
      ],
    ];

    return $output;
  }

  /**
   * {@inheritDoc}
   */
  public function getModuleName() : string {
    return 'Unomi Segments';
  }

  /**
   * {@inheritDoc}
   */
  public function getSettingsFormRoute() : string {
    return 'unomi_segments.settings_form';
  }

}
